==> zio-aws-cloudfront_2.13-5.17.104.1-sources.jar: zio/aws/cloudfront/model/GetKeyGroupResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetKeyGroupResponse(
    keyGroup: Option[zio.aws.cloudfront.model.KeyGroup] = None,
    eTag: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse = {
    import GetKeyGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse
      .builder()
      .optionallyWith(keyGroup.map(value => value.buildAwsValue()))(_.keyGroup)
      .optionallyWith(eTag.map(value => value: java.lang.String))(_.eTag)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.GetKeyGroupResponse.ReadOnly =
    zio.aws.cloudfront.model.GetKeyGroupResponse.wrap(buildAwsValue())
}
object GetKeyGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.GetKeyGroupResponse =
      zio.aws.cloudfront.model.GetKeyGroupResponse(
        keyGroup.map(value => value.asEditable),
        eTag.map(value => value)
      )
    def keyGroup: Option[zio.aws.cloudfront.model.KeyGroup.ReadOnly]
    def eTag: Option[String]
    def getKeyGroup
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.KeyGroup.ReadOnly] =
      AwsError.unwrapOptionField("keyGroup", keyGroup)
    def getETag: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("eTag", eTag)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse
  ) extends zio.aws.cloudfront.model.GetKeyGroupResponse.ReadOnly {
    override val keyGroup: Option[zio.aws.cloudfront.model.KeyGroup.ReadOnly] =
      scala
        .Option(impl.keyGroup())
        .map(value => zio.aws.cloudfront.model.KeyGroup.wrap(value))
    override val eTag: Option[String] =
      scala.Option(impl.eTag()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse
  ): zio.aws.cloudfront.model.GetKeyGroupResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.19.17.1-sources.jar: zio/aws/cloudfront/model/GetKeyGroupResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetKeyGroupResponse(
    keyGroup: Optional[zio.aws.cloudfront.model.KeyGroup] = Optional.Absent,
    eTag: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse = {
    import GetKeyGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse
      .builder()
      .optionallyWith(keyGroup.map(value => value.buildAwsValue()))(_.keyGroup)
      .optionallyWith(eTag.map(value => value: java.lang.String))(_.eTag)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.GetKeyGroupResponse.ReadOnly =
    zio.aws.cloudfront.model.GetKeyGroupResponse.wrap(buildAwsValue())
}
object GetKeyGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.GetKeyGroupResponse =
      zio.aws.cloudfront.model.GetKeyGroupResponse(
        keyGroup.map(value => value.asEditable),
        eTag.map(value => value)
      )
    def keyGroup: Optional[zio.aws.cloudfront.model.KeyGroup.ReadOnly]
    def eTag: Optional[String]
    def getKeyGroup
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.KeyGroup.ReadOnly] =
      AwsError.unwrapOptionField("keyGroup", keyGroup)
    def getETag: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("eTag", eTag)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse
  ) extends zio.aws.cloudfront.model.GetKeyGroupResponse.ReadOnly {
    override val keyGroup
        : Optional[zio.aws.cloudfront.model.KeyGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.keyGroup())
        .map(value => zio.aws.cloudfront.model.KeyGroup.wrap(value))
    override val eTag: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.eTag())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.GetKeyGroupResponse
  ): zio.aws.cloudfront.model.GetKeyGroupResponse.ReadOnly = new Wrapper(impl)
}
